# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.analytics.admin_v1alpha import gapic_version as package_version

__version__ = package_version.__version__


from .services.analytics_admin_service import (
    AnalyticsAdminServiceAsyncClient,
    AnalyticsAdminServiceClient,
)
from .types.access_report import (
    AccessBetweenFilter,
    AccessDateRange,
    AccessDimension,
    AccessDimensionHeader,
    AccessDimensionValue,
    AccessFilter,
    AccessFilterExpression,
    AccessFilterExpressionList,
    AccessInListFilter,
    AccessMetric,
    AccessMetricHeader,
    AccessMetricValue,
    AccessNumericFilter,
    AccessOrderBy,
    AccessQuota,
    AccessQuotaStatus,
    AccessRow,
    AccessStringFilter,
    NumericValue,
)
from .types.analytics_admin import (
    AcknowledgeUserDataCollectionRequest,
    AcknowledgeUserDataCollectionResponse,
    ApproveDisplayVideo360AdvertiserLinkProposalRequest,
    ApproveDisplayVideo360AdvertiserLinkProposalResponse,
    ArchiveAudienceRequest,
    ArchiveCustomDimensionRequest,
    ArchiveCustomMetricRequest,
    AuditUserLinksRequest,
    AuditUserLinksResponse,
    BatchCreateAccessBindingsRequest,
    BatchCreateAccessBindingsResponse,
    BatchCreateUserLinksRequest,
    BatchCreateUserLinksResponse,
    BatchDeleteAccessBindingsRequest,
    BatchDeleteUserLinksRequest,
    BatchGetAccessBindingsRequest,
    BatchGetAccessBindingsResponse,
    BatchGetUserLinksRequest,
    BatchGetUserLinksResponse,
    BatchUpdateAccessBindingsRequest,
    BatchUpdateAccessBindingsResponse,
    BatchUpdateUserLinksRequest,
    BatchUpdateUserLinksResponse,
    CancelDisplayVideo360AdvertiserLinkProposalRequest,
    CreateAccessBindingRequest,
    CreateAdSenseLinkRequest,
    CreateAudienceRequest,
    CreateChannelGroupRequest,
    CreateConnectedSiteTagRequest,
    CreateConnectedSiteTagResponse,
    CreateConversionEventRequest,
    CreateCustomDimensionRequest,
    CreateCustomMetricRequest,
    CreateDataStreamRequest,
    CreateDisplayVideo360AdvertiserLinkProposalRequest,
    CreateDisplayVideo360AdvertiserLinkRequest,
    CreateEventCreateRuleRequest,
    CreateExpandedDataSetRequest,
    CreateFirebaseLinkRequest,
    CreateGoogleAdsLinkRequest,
    CreateMeasurementProtocolSecretRequest,
    CreatePropertyRequest,
    CreateSearchAds360LinkRequest,
    CreateSKAdNetworkConversionValueSchemaRequest,
    CreateUserLinkRequest,
    DeleteAccessBindingRequest,
    DeleteAccountRequest,
    DeleteAdSenseLinkRequest,
    DeleteChannelGroupRequest,
    DeleteConnectedSiteTagRequest,
    DeleteConversionEventRequest,
    DeleteDataStreamRequest,
    DeleteDisplayVideo360AdvertiserLinkProposalRequest,
    DeleteDisplayVideo360AdvertiserLinkRequest,
    DeleteEventCreateRuleRequest,
    DeleteExpandedDataSetRequest,
    DeleteFirebaseLinkRequest,
    DeleteGoogleAdsLinkRequest,
    DeleteMeasurementProtocolSecretRequest,
    DeletePropertyRequest,
    DeleteSearchAds360LinkRequest,
    DeleteSKAdNetworkConversionValueSchemaRequest,
    DeleteUserLinkRequest,
    FetchAutomatedGa4ConfigurationOptOutRequest,
    FetchAutomatedGa4ConfigurationOptOutResponse,
    FetchConnectedGa4PropertyRequest,
    FetchConnectedGa4PropertyResponse,
    GetAccessBindingRequest,
    GetAccountRequest,
    GetAdSenseLinkRequest,
    GetAttributionSettingsRequest,
    GetAudienceRequest,
    GetBigQueryLinkRequest,
    GetChannelGroupRequest,
    GetConversionEventRequest,
    GetCustomDimensionRequest,
    GetCustomMetricRequest,
    GetDataRetentionSettingsRequest,
    GetDataSharingSettingsRequest,
    GetDataStreamRequest,
    GetDisplayVideo360AdvertiserLinkProposalRequest,
    GetDisplayVideo360AdvertiserLinkRequest,
    GetEnhancedMeasurementSettingsRequest,
    GetEventCreateRuleRequest,
    GetExpandedDataSetRequest,
    GetGlobalSiteTagRequest,
    GetGoogleSignalsSettingsRequest,
    GetMeasurementProtocolSecretRequest,
    GetPropertyRequest,
    GetSearchAds360LinkRequest,
    GetSKAdNetworkConversionValueSchemaRequest,
    GetUserLinkRequest,
    ListAccessBindingsRequest,
    ListAccessBindingsResponse,
    ListAccountsRequest,
    ListAccountsResponse,
    ListAccountSummariesRequest,
    ListAccountSummariesResponse,
    ListAdSenseLinksRequest,
    ListAdSenseLinksResponse,
    ListAudiencesRequest,
    ListAudiencesResponse,
    ListBigQueryLinksRequest,
    ListBigQueryLinksResponse,
    ListChannelGroupsRequest,
    ListChannelGroupsResponse,
    ListConnectedSiteTagsRequest,
    ListConnectedSiteTagsResponse,
    ListConversionEventsRequest,
    ListConversionEventsResponse,
    ListCustomDimensionsRequest,
    ListCustomDimensionsResponse,
    ListCustomMetricsRequest,
    ListCustomMetricsResponse,
    ListDataStreamsRequest,
    ListDataStreamsResponse,
    ListDisplayVideo360AdvertiserLinkProposalsRequest,
    ListDisplayVideo360AdvertiserLinkProposalsResponse,
    ListDisplayVideo360AdvertiserLinksRequest,
    ListDisplayVideo360AdvertiserLinksResponse,
    ListEventCreateRulesRequest,
    ListEventCreateRulesResponse,
    ListExpandedDataSetsRequest,
    ListExpandedDataSetsResponse,
    ListFirebaseLinksRequest,
    ListFirebaseLinksResponse,
    ListGoogleAdsLinksRequest,
    ListGoogleAdsLinksResponse,
    ListMeasurementProtocolSecretsRequest,
    ListMeasurementProtocolSecretsResponse,
    ListPropertiesRequest,
    ListPropertiesResponse,
    ListSearchAds360LinksRequest,
    ListSearchAds360LinksResponse,
    ListSKAdNetworkConversionValueSchemasRequest,
    ListSKAdNetworkConversionValueSchemasResponse,
    ListUserLinksRequest,
    ListUserLinksResponse,
    ProvisionAccountTicketRequest,
    ProvisionAccountTicketResponse,
    RunAccessReportRequest,
    RunAccessReportResponse,
    SearchChangeHistoryEventsRequest,
    SearchChangeHistoryEventsResponse,
    SetAutomatedGa4ConfigurationOptOutRequest,
    SetAutomatedGa4ConfigurationOptOutResponse,
    UpdateAccessBindingRequest,
    UpdateAccountRequest,
    UpdateAttributionSettingsRequest,
    UpdateAudienceRequest,
    UpdateChannelGroupRequest,
    UpdateConversionEventRequest,
    UpdateCustomDimensionRequest,
    UpdateCustomMetricRequest,
    UpdateDataRetentionSettingsRequest,
    UpdateDataStreamRequest,
    UpdateDisplayVideo360AdvertiserLinkRequest,
    UpdateEnhancedMeasurementSettingsRequest,
    UpdateEventCreateRuleRequest,
    UpdateExpandedDataSetRequest,
    UpdateGoogleAdsLinkRequest,
    UpdateGoogleSignalsSettingsRequest,
    UpdateMeasurementProtocolSecretRequest,
    UpdatePropertyRequest,
    UpdateSearchAds360LinkRequest,
    UpdateSKAdNetworkConversionValueSchemaRequest,
    UpdateUserLinkRequest,
)
from .types.audience import (
    Audience,
    AudienceDimensionOrMetricFilter,
    AudienceEventFilter,
    AudienceEventTrigger,
    AudienceFilterClause,
    AudienceFilterExpression,
    AudienceFilterExpressionList,
    AudienceFilterScope,
    AudienceSequenceFilter,
    AudienceSimpleFilter,
)
from .types.channel_group import (
    ChannelGroup,
    ChannelGroupFilter,
    ChannelGroupFilterExpression,
    ChannelGroupFilterExpressionList,
    GroupingRule,
)
from .types.event_create_and_edit import (
    EventCreateRule,
    MatchingCondition,
    ParameterMutation,
)
from .types.expanded_data_set import (
    ExpandedDataSet,
    ExpandedDataSetFilter,
    ExpandedDataSetFilterExpression,
    ExpandedDataSetFilterExpressionList,
)
from .types.resources import (
    AccessBinding,
    Account,
    AccountSummary,
    ActionType,
    ActorType,
    AdSenseLink,
    AttributionSettings,
    AuditUserLink,
    BigQueryLink,
    ChangeHistoryChange,
    ChangeHistoryEvent,
    ChangeHistoryResourceType,
    CoarseValue,
    ConnectedSiteTag,
    ConversionEvent,
    ConversionValues,
    CustomDimension,
    CustomMetric,
    DataRetentionSettings,
    DataSharingSettings,
    DataStream,
    DisplayVideo360AdvertiserLink,
    DisplayVideo360AdvertiserLinkProposal,
    EnhancedMeasurementSettings,
    EventMapping,
    FirebaseLink,
    GlobalSiteTag,
    GoogleAdsLink,
    GoogleSignalsConsent,
    GoogleSignalsSettings,
    GoogleSignalsState,
    IndustryCategory,
    LinkProposalInitiatingProduct,
    LinkProposalState,
    LinkProposalStatusDetails,
    MeasurementProtocolSecret,
    PostbackWindow,
    Property,
    PropertySummary,
    PropertyType,
    SearchAds360Link,
    ServiceLevel,
    SKAdNetworkConversionValueSchema,
    UserLink,
)

__all__ = (
    "AnalyticsAdminServiceAsyncClient",
    "AccessBetweenFilter",
    "AccessBinding",
    "AccessDateRange",
    "AccessDimension",
    "AccessDimensionHeader",
    "AccessDimensionValue",
    "AccessFilter",
    "AccessFilterExpression",
    "AccessFilterExpressionList",
    "AccessInListFilter",
    "AccessMetric",
    "AccessMetricHeader",
    "AccessMetricValue",
    "AccessNumericFilter",
    "AccessOrderBy",
    "AccessQuota",
    "AccessQuotaStatus",
    "AccessRow",
    "AccessStringFilter",
    "Account",
    "AccountSummary",
    "AcknowledgeUserDataCollectionRequest",
    "AcknowledgeUserDataCollectionResponse",
    "ActionType",
    "ActorType",
    "AdSenseLink",
    "AnalyticsAdminServiceClient",
    "ApproveDisplayVideo360AdvertiserLinkProposalRequest",
    "ApproveDisplayVideo360AdvertiserLinkProposalResponse",
    "ArchiveAudienceRequest",
    "ArchiveCustomDimensionRequest",
    "ArchiveCustomMetricRequest",
    "AttributionSettings",
    "Audience",
    "AudienceDimensionOrMetricFilter",
    "AudienceEventFilter",
    "AudienceEventTrigger",
    "AudienceFilterClause",
    "AudienceFilterExpression",
    "AudienceFilterExpressionList",
    "AudienceFilterScope",
    "AudienceSequenceFilter",
    "AudienceSimpleFilter",
    "AuditUserLink",
    "AuditUserLinksRequest",
    "AuditUserLinksResponse",
    "BatchCreateAccessBindingsRequest",
    "BatchCreateAccessBindingsResponse",
    "BatchCreateUserLinksRequest",
    "BatchCreateUserLinksResponse",
    "BatchDeleteAccessBindingsRequest",
    "BatchDeleteUserLinksRequest",
    "BatchGetAccessBindingsRequest",
    "BatchGetAccessBindingsResponse",
    "BatchGetUserLinksRequest",
    "BatchGetUserLinksResponse",
    "BatchUpdateAccessBindingsRequest",
    "BatchUpdateAccessBindingsResponse",
    "BatchUpdateUserLinksRequest",
    "BatchUpdateUserLinksResponse",
    "BigQueryLink",
    "CancelDisplayVideo360AdvertiserLinkProposalRequest",
    "ChangeHistoryChange",
    "ChangeHistoryEvent",
    "ChangeHistoryResourceType",
    "ChannelGroup",
    "ChannelGroupFilter",
    "ChannelGroupFilterExpression",
    "ChannelGroupFilterExpressionList",
    "CoarseValue",
    "ConnectedSiteTag",
    "ConversionEvent",
    "ConversionValues",
    "CreateAccessBindingRequest",
    "CreateAdSenseLinkRequest",
    "CreateAudienceRequest",
    "CreateChannelGroupRequest",
    "CreateConnectedSiteTagRequest",
    "CreateConnectedSiteTagResponse",
    "CreateConversionEventRequest",
    "CreateCustomDimensionRequest",
    "CreateCustomMetricRequest",
    "CreateDataStreamRequest",
    "CreateDisplayVideo360AdvertiserLinkProposalRequest",
    "CreateDisplayVideo360AdvertiserLinkRequest",
    "CreateEventCreateRuleRequest",
    "CreateExpandedDataSetRequest",
    "CreateFirebaseLinkRequest",
    "CreateGoogleAdsLinkRequest",
    "CreateMeasurementProtocolSecretRequest",
    "CreatePropertyRequest",
    "CreateSKAdNetworkConversionValueSchemaRequest",
    "CreateSearchAds360LinkRequest",
    "CreateUserLinkRequest",
    "CustomDimension",
    "CustomMetric",
    "DataRetentionSettings",
    "DataSharingSettings",
    "DataStream",
    "DeleteAccessBindingRequest",
    "DeleteAccountRequest",
    "DeleteAdSenseLinkRequest",
    "DeleteChannelGroupRequest",
    "DeleteConnectedSiteTagRequest",
    "DeleteConversionEventRequest",
    "DeleteDataStreamRequest",
    "DeleteDisplayVideo360AdvertiserLinkProposalRequest",
    "DeleteDisplayVideo360AdvertiserLinkRequest",
    "DeleteEventCreateRuleRequest",
    "DeleteExpandedDataSetRequest",
    "DeleteFirebaseLinkRequest",
    "DeleteGoogleAdsLinkRequest",
    "DeleteMeasurementProtocolSecretRequest",
    "DeletePropertyRequest",
    "DeleteSKAdNetworkConversionValueSchemaRequest",
    "DeleteSearchAds360LinkRequest",
    "DeleteUserLinkRequest",
    "DisplayVideo360AdvertiserLink",
    "DisplayVideo360AdvertiserLinkProposal",
    "EnhancedMeasurementSettings",
    "EventCreateRule",
    "EventMapping",
    "ExpandedDataSet",
    "ExpandedDataSetFilter",
    "ExpandedDataSetFilterExpression",
    "ExpandedDataSetFilterExpressionList",
    "FetchAutomatedGa4ConfigurationOptOutRequest",
    "FetchAutomatedGa4ConfigurationOptOutResponse",
    "FetchConnectedGa4PropertyRequest",
    "FetchConnectedGa4PropertyResponse",
    "FirebaseLink",
    "GetAccessBindingRequest",
    "GetAccountRequest",
    "GetAdSenseLinkRequest",
    "GetAttributionSettingsRequest",
    "GetAudienceRequest",
    "GetBigQueryLinkRequest",
    "GetChannelGroupRequest",
    "GetConversionEventRequest",
    "GetCustomDimensionRequest",
    "GetCustomMetricRequest",
    "GetDataRetentionSettingsRequest",
    "GetDataSharingSettingsRequest",
    "GetDataStreamRequest",
    "GetDisplayVideo360AdvertiserLinkProposalRequest",
    "GetDisplayVideo360AdvertiserLinkRequest",
    "GetEnhancedMeasurementSettingsRequest",
    "GetEventCreateRuleRequest",
    "GetExpandedDataSetRequest",
    "GetGlobalSiteTagRequest",
    "GetGoogleSignalsSettingsRequest",
    "GetMeasurementProtocolSecretRequest",
    "GetPropertyRequest",
    "GetSKAdNetworkConversionValueSchemaRequest",
    "GetSearchAds360LinkRequest",
    "GetUserLinkRequest",
    "GlobalSiteTag",
    "GoogleAdsLink",
    "GoogleSignalsConsent",
    "GoogleSignalsSettings",
    "GoogleSignalsState",
    "GroupingRule",
    "IndustryCategory",
    "LinkProposalInitiatingProduct",
    "LinkProposalState",
    "LinkProposalStatusDetails",
    "ListAccessBindingsRequest",
    "ListAccessBindingsResponse",
    "ListAccountSummariesRequest",
    "ListAccountSummariesResponse",
    "ListAccountsRequest",
    "ListAccountsResponse",
    "ListAdSenseLinksRequest",
    "ListAdSenseLinksResponse",
    "ListAudiencesRequest",
    "ListAudiencesResponse",
    "ListBigQueryLinksRequest",
    "ListBigQueryLinksResponse",
    "ListChannelGroupsRequest",
    "ListChannelGroupsResponse",
    "ListConnectedSiteTagsRequest",
    "ListConnectedSiteTagsResponse",
    "ListConversionEventsRequest",
    "ListConversionEventsResponse",
    "ListCustomDimensionsRequest",
    "ListCustomDimensionsResponse",
    "ListCustomMetricsRequest",
    "ListCustomMetricsResponse",
    "ListDataStreamsRequest",
    "ListDataStreamsResponse",
    "ListDisplayVideo360AdvertiserLinkProposalsRequest",
    "ListDisplayVideo360AdvertiserLinkProposalsResponse",
    "ListDisplayVideo360AdvertiserLinksRequest",
    "ListDisplayVideo360AdvertiserLinksResponse",
    "ListEventCreateRulesRequest",
    "ListEventCreateRulesResponse",
    "ListExpandedDataSetsRequest",
    "ListExpandedDataSetsResponse",
    "ListFirebaseLinksRequest",
    "ListFirebaseLinksResponse",
    "ListGoogleAdsLinksRequest",
    "ListGoogleAdsLinksResponse",
    "ListMeasurementProtocolSecretsRequest",
    "ListMeasurementProtocolSecretsResponse",
    "ListPropertiesRequest",
    "ListPropertiesResponse",
    "ListSKAdNetworkConversionValueSchemasRequest",
    "ListSKAdNetworkConversionValueSchemasResponse",
    "ListSearchAds360LinksRequest",
    "ListSearchAds360LinksResponse",
    "ListUserLinksRequest",
    "ListUserLinksResponse",
    "MatchingCondition",
    "MeasurementProtocolSecret",
    "NumericValue",
    "ParameterMutation",
    "PostbackWindow",
    "Property",
    "PropertySummary",
    "PropertyType",
    "ProvisionAccountTicketRequest",
    "ProvisionAccountTicketResponse",
    "RunAccessReportRequest",
    "RunAccessReportResponse",
    "SKAdNetworkConversionValueSchema",
    "SearchAds360Link",
    "SearchChangeHistoryEventsRequest",
    "SearchChangeHistoryEventsResponse",
    "ServiceLevel",
    "SetAutomatedGa4ConfigurationOptOutRequest",
    "SetAutomatedGa4ConfigurationOptOutResponse",
    "UpdateAccessBindingRequest",
    "UpdateAccountRequest",
    "UpdateAttributionSettingsRequest",
    "UpdateAudienceRequest",
    "UpdateChannelGroupRequest",
    "UpdateConversionEventRequest",
    "UpdateCustomDimensionRequest",
    "UpdateCustomMetricRequest",
    "UpdateDataRetentionSettingsRequest",
    "UpdateDataStreamRequest",
    "UpdateDisplayVideo360AdvertiserLinkRequest",
    "UpdateEnhancedMeasurementSettingsRequest",
    "UpdateEventCreateRuleRequest",
    "UpdateExpandedDataSetRequest",
    "UpdateGoogleAdsLinkRequest",
    "UpdateGoogleSignalsSettingsRequest",
    "UpdateMeasurementProtocolSecretRequest",
    "UpdatePropertyRequest",
    "UpdateSKAdNetworkConversionValueSchemaRequest",
    "UpdateSearchAds360LinkRequest",
    "UpdateUserLinkRequest",
    "UserLink",
)
